AllowedTools class

Configuration for allowed tools.

Constructors

AllowedTools({InteractionToolChoiceType? mode, List<String>? tools})
Creates an AllowedTools instance.
const
AllowedTools.fromJson(Map<String, dynamic> json)
Creates an AllowedTools from JSON.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
mode InteractionToolChoiceType?
The mode of the tool choice.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tools List<String>?
The names of the allowed tools.
final

Methods

copyWith({Object? mode = unsetCopyWithValue, Object? tools = unsetCopyWithValue}) AllowedTools
Creates a copy with replaced values.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Converts to JSON.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited