AudioContent class

An audio content block.

Inheritance

Constructors

AudioContent({String? data, String? uri, String? mimeType})
Creates an AudioContent instance.
const
AudioContent.fromJson(Map<String, dynamic> json)
Creates an AudioContent from JSON.
factory

Properties

data String?
Base64-encoded audio data.
final
hashCode int
The hash code for this object.
no setterinherited
mimeType String?
The MIME type of the audio.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String
The type discriminator for this content.
no setteroverride
uri String?
URI of the audio.
final

Methods

copyWith({Object? data = unsetCopyWithValue, Object? uri = unsetCopyWithValue, Object? mimeType = unsetCopyWithValue}) AudioContent
Creates a copy with replaced values.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Converts to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited