CachedContentUsageMetadata class

Usage metadata for cached content.

Constructors

CachedContentUsageMetadata({int? totalTokenCount})
Creates a CachedContentUsageMetadata.
const
CachedContentUsageMetadata.fromJson(Map<String, dynamic> json)
Creates a CachedContentUsageMetadata from JSON.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
totalTokenCount int?
Total number of tokens in the cached content.
final

Methods

copyWith({Object? totalTokenCount = unsetCopyWithValue}) CachedContentUsageMetadata
Creates a copy with replaced values.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Converts to JSON.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited