CodeExecutionCallStepArguments class

The arguments to pass to the code execution tool.

Constructors

CodeExecutionCallStepArguments({String? code, CodeExecutionLanguage? language})
Creates a CodeExecutionCallStepArguments instance.
const
CodeExecutionCallStepArguments.fromJson(Map<String, dynamic> json)
Creates a CodeExecutionCallStepArguments from JSON.
factory

Properties

code String?
The code to be executed.
final
hashCode int
The hash code for this object.
no setterinherited
language CodeExecutionLanguage?
Programming language of the code.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({Object? code = unsetCopyWithValue, Object? language = unsetCopyWithValue}) CodeExecutionCallStepArguments
Creates a copy with replaced values.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Converts to JSON.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited