CodeExecutionResult class

Result of executing the ExecutableCode.

Constructors

CodeExecutionResult({String? id, required Outcome outcome, required String output})
Creates a CodeExecutionResult.
const
CodeExecutionResult.fromJson(Map<String, dynamic> json)
Creates a CodeExecutionResult from JSON.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
id String?
Optional identifier of the corresponding ExecutableCode part, used to match the result back to the code that produced it.
final
outcome Outcome
Outcome of the code execution.
final
output String
Contains stdout when code execution is successful, stderr or other description otherwise.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({Object? id = unsetCopyWithValue, Object? outcome = unsetCopyWithValue, Object? output = unsetCopyWithValue}) CodeExecutionResult
Creates a copy with replaced values.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Converts to JSON.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited