CodeExecutionResultPart class
Result from code execution.
Constructors
- CodeExecutionResultPart(CodeExecutionResult codeExecutionResult)
-
Creates a CodeExecutionResultPart.
const
Properties
- codeExecutionResult → CodeExecutionResult
-
Code execution result.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{Object? codeExecutionResult = unsetCopyWithValue}) → CodeExecutionResultPart - Creates a copy with replaced values.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Converts to JSON.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited