CodeExecutionTool class
A tool that allows the model to execute code.
- Inheritance
-
- Object
- InteractionTool
- CodeExecutionTool
Constructors
- CodeExecutionTool()
-
Creates a CodeExecutionTool instance.
const
-
CodeExecutionTool.fromJson(Map<
String, dynamic> _) -
Creates a CodeExecutionTool from JSON.
factory
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Converts to JSON.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited