Condition class

Filter condition applicable to a single key.

Constructors

Condition({double? numericValue, required String operation, String? stringValue})
Creates a Condition.
const
Condition.fromJson(Map<String, dynamic> json)
Creates a Condition from JSON.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
numericValue double?
The numeric value to filter the metadata on.
final
operation String
Required. Operator applied to the given key-value pair to trigger the condition.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stringValue String?
The string value to filter the metadata on.
final

Methods

copyWith({Object? numericValue = unsetCopyWithValue, Object? operation = unsetCopyWithValue, Object? stringValue = unsetCopyWithValue}) Condition
Creates a copy with replaced values.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Converts to JSON.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited