EmbedContentBatchStats class

Stats about an embed batch operation.

Constructors

EmbedContentBatchStats({int? requestCount, int? successfulRequestCount, int? failedRequestCount, int? pendingRequestCount})
Creates an EmbedContentBatchStats.
const
EmbedContentBatchStats.fromJson(Map<String, dynamic> json)
Creates an EmbedContentBatchStats from JSON.
factory

Properties

failedRequestCount int?
The number of requests that failed to be processed.
final
hashCode int
The hash code for this object.
no setterinherited
pendingRequestCount int?
The number of requests that are still pending processing.
final
requestCount int?
The number of requests in the batch.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
successfulRequestCount int?
The number of requests that were successfully processed.
final

Methods

copyWith({Object? requestCount = unsetCopyWithValue, Object? successfulRequestCount = unsetCopyWithValue, Object? failedRequestCount = unsetCopyWithValue, Object? pendingRequestCount = unsetCopyWithValue}) EmbedContentBatchStats
Creates a copy with replaced values.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Converts to JSON.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited