FileCitation class

A file citation annotation.

Inheritance

Constructors

FileCitation({int? startIndex, int? endIndex, String? fileName, String? documentUri, String? source, Map<String, dynamic>? customMetadata, String? mediaId, int? pageNumber})
Creates a FileCitation instance.
const
FileCitation.fromJson(Map<String, dynamic> json)
Creates a FileCitation from JSON.
factory

Properties

customMetadata Map<String, dynamic>?
User provided metadata about the retrieved context.
final
documentUri String?
The URI of the cited document.
final
endIndex int?
End of the attributed segment, exclusive.
final
fileName String?
The name of the cited file.
final
hashCode int
The hash code for this object.
no setterinherited
mediaId String?
Media ID for image citations, if applicable.
final
pageNumber int?
Page number of the cited document, if applicable.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
source String?
The source identifier.
final
startIndex int?
Start of segment of the response that is attributed to this source.
final

Methods

copyWith({Object? startIndex = unsetCopyWithValue, Object? endIndex = unsetCopyWithValue, Object? fileName = unsetCopyWithValue, Object? documentUri = unsetCopyWithValue, Object? source = unsetCopyWithValue, Object? customMetadata = unsetCopyWithValue, Object? mediaId = unsetCopyWithValue, Object? pageNumber = unsetCopyWithValue}) FileCitation
Creates a copy with replaced values.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Converts to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited