FunctionCallPart class

Model's request to call a function.

Inheritance

Constructors

FunctionCallPart(FunctionCall functionCall, {List<int>? thoughtSignature})
Creates a FunctionCallPart.
const

Properties

functionCall FunctionCall
Function call.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
thoughtSignature List<int>?
Optional opaque thought signature bytes.
final

Methods

copyWith({Object? functionCall = unsetCopyWithValue, Object? thoughtSignature = unsetCopyWithValue}) FunctionCallPart
Creates a copy with replaced values.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Converts to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited