FunctionResultDelta class

A streamed delta for a function tool result.

Inheritance

Constructors

FunctionResultDelta({String? callId, ToolResult? result, String? name, bool? isError})
Creates a FunctionResultDelta instance.
const
FunctionResultDelta.fromJson(Map<String, dynamic> json)
Creates a FunctionResultDelta from JSON.
factory

Properties

callId String?
ID matching the corresponding function call.
final
hashCode int
The hash code for this object.
no setterinherited
isError bool?
Whether the tool call resulted in an error.
final
name String?
The name of the tool that was called.
final
result ToolResult?
The result of the tool call.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String
The type discriminator for this delta.
no setteroverride

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Converts to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited