FunctionTool class

A function tool that can be called by the model.

Inheritance

Constructors

FunctionTool({String? name, String? description, Map<String, dynamic>? parameters})
Creates a FunctionTool instance.
const
FunctionTool.fromJson(Map<String, dynamic> json)
Creates a FunctionTool from JSON.
factory

Properties

description String?
A description of the function.
final
hashCode int
The hash code for this object.
no setterinherited
name String?
The name of the function.
final
parameters Map<String, dynamic>?
The JSON Schema for the function's parameters.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String
The type discriminator for this tool.
no setteroverride

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Converts to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited