inputConfig property
Input configuration of the instances on which batch processing is performed.
Implementation
final InputConfig? inputConfig;
Input configuration of the instances on which batch processing is performed.
final InputConfig? inputConfig;