GoogleAIException class sealed

Base sealed class for all GoogleAI exceptions.

Subtypes:

Implemented types
Implementers

Properties

cause Exception?
Original exception that caused this exception (for exception chaining). Used to preserve context through retry attempts and error transformations.
no setter
hashCode int
The hash code for this object.
no setterinherited
message String
Human-readable error message.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stackTrace StackTrace?
Optional stack trace.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited