GoogleSearchResult class

A Google Search result item.

Constructors

GoogleSearchResult({String? url, String? title})
Creates a GoogleSearchResult instance.
const
GoogleSearchResult.fromJson(Map<String, dynamic> json)
Creates a GoogleSearchResult from JSON.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
title String?
The title of the search result.
final
url String?
The URL of the search result.
final

Methods

copyWith({Object? url = unsetCopyWithValue, Object? title = unsetCopyWithValue}) GoogleSearchResult
Creates a copy with replaced values.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Converts to JSON.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited