ImageDelta class

An image delta update.

Inheritance

Constructors

ImageDelta({String? data, String? uri, String? mimeType, InteractionMediaResolution? resolution})
Creates an ImageDelta instance.
const
ImageDelta.fromJson(Map<String, dynamic> json)
Creates an ImageDelta from JSON.
factory

Properties

data String?
Base64-encoded image data.
final
hashCode int
The hash code for this object.
no setterinherited
mimeType String?
The MIME type of the image.
final
resolution InteractionMediaResolution?
The resolution of the media.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type String
The type discriminator for this delta.
no setteroverride
uri String?
URI of the image.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Converts to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited