InlinedEmbedContentResponses class

A list of inlined embed responses from batch processing.

Constructors

InlinedEmbedContentResponses({List<InlinedEmbedContentResponse>? inlinedResponses})
Creates an InlinedEmbedContentResponses.
const
InlinedEmbedContentResponses.fromJson(Map<String, dynamic> json)
Creates an InlinedEmbedContentResponses from JSON.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
inlinedResponses List<InlinedEmbedContentResponse>?
The responses to the requests in the batch.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({Object? inlinedResponses = unsetCopyWithValue}) InlinedEmbedContentResponses
Creates a copy with replaced values.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Converts to JSON.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited