InteractionCompletedEvent class

An event indicating that an interaction has completed.

Carries the completed Interaction resource. Per the spec, the steps list is empty on this event to reduce payload size — the caller should reconstruct steps from preceding step.delta and step.start/step.stop events.

Inheritance

Constructors

InteractionCompletedEvent({required Interaction interaction, StreamMetadata? metadata, String? eventId})
Creates an InteractionCompletedEvent instance.
const
InteractionCompletedEvent.fromJson(Map<String, dynamic> json)
Creates an InteractionCompletedEvent from JSON.
factory

Properties

eventId String?
The event ID token to resume the stream from this event.
finalinherited
eventType String
The event type discriminator.
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
interaction Interaction
The completed interaction.
final
metadata StreamMetadata?
Optional metadata accompanying this streamed event.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Converts to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited