InteractionError class

An error from an interaction.

Constructors

InteractionError({String? message, String? code})
Creates an InteractionError instance.
const
InteractionError.fromJson(Map<String, dynamic> json)
Creates an InteractionError from JSON.
factory

Properties

code String?
The error code.
final
hashCode int
The hash code for this object.
no setterinherited
message String?
The error message.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Converts to JSON.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited