InteractionImageConfig class

The configuration for image interaction.

Constructors

InteractionImageConfig({String? aspectRatio, String? imageSize})
Creates an InteractionImageConfig instance.
const
InteractionImageConfig.fromJson(Map<String, dynamic> json)
Creates an InteractionImageConfig from JSON.
factory

Properties

aspectRatio String?
The aspect ratio of the generated image.
final
hashCode int
The hash code for this object.
no setterinherited
imageSize String?
The size of the generated image.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({Object? aspectRatio = unsetCopyWithValue, Object? imageSize = unsetCopyWithValue}) InteractionImageConfig
Creates a copy with replaced values.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Converts to JSON.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited