InteractionResponseModality enum

The modality of a response.

Inheritance
Available extensions

Values

text → const InteractionResponseModality

Text response modality.

image → const InteractionResponseModality

Image response modality.

audio → const InteractionResponseModality

Audio response modality.

video → const InteractionResponseModality

Video response modality.

document → const InteractionResponseModality

Document response modality.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<InteractionResponseModality>
A constant List of the values in this enum, in order of their declaration.