InteractionSingleResponseFormat class
A single InteractionResponseFormat response-format configuration.
- Inheritance
-
- Object
- InteractionResponseFormatConfig
- InteractionSingleResponseFormat
Constructors
- InteractionSingleResponseFormat(InteractionResponseFormat format)
-
Creates an InteractionSingleResponseFormat.
const
Properties
- format → InteractionResponseFormat
-
The response format.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Object -
Converts to its JSON representation (an object or a list of objects).
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited