InteractionTool class sealed
A tool that can be used by the model.
This is a sealed class with subtypes for different tool types.
Constructors
-
InteractionTool.fromJson(Map<
String, dynamic> json) -
Creates an InteractionTool from JSON.
factory
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Converts to JSON.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited