MetadataFilter class

User provided filter to limit retrieval based on Chunk or Document level metadata values.

Constructors

MetadataFilter({required List<Condition> conditions, required String key})
Creates a MetadataFilter.
const
MetadataFilter.fromJson(Map<String, dynamic> json)
Creates a MetadataFilter from JSON.
factory

Properties

conditions List<Condition>
Required. The Conditions for the given key that will trigger this filter. Multiple Conditions are joined by logical ORs.
final
hashCode int
The hash code for this object.
no setterinherited
key String
Required. The key of the metadata to filter on.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({Object? conditions = unsetCopyWithValue, Object? key = unsetCopyWithValue}) MetadataFilter
Creates a copy with replaced values.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Converts to JSON.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited