PredictResponse class

Response message for Predict operation.

Contains the prediction outputs from the model.

Constructors

PredictResponse({required List predictions})
Creates a PredictResponse.
const
PredictResponse.fromJson(Map<String, dynamic> json)
Creates a PredictResponse from JSON.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
predictions List
The outputs of the prediction call.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({Object? predictions = unsetCopyWithValue}) PredictResponse
Creates a copy with replaced values.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Converts to JSON.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited