ResponseFormatConfig class

Configuration for the response output format.

Allows specifying output configuration per modality (text, audio, image) in a flat structure.

Constructors

ResponseFormatConfig({TextResponseFormat? text, AudioResponseFormat? audio, ImageResponseFormat? image})
Creates a ResponseFormatConfig.
const
ResponseFormatConfig.fromJson(Map<String, dynamic> json)
Creates a ResponseFormatConfig from JSON.
factory

Properties

audio AudioResponseFormat?
Audio output format configuration.
final
hashCode int
The hash code for this object.
no setterinherited
image ImageResponseFormat?
Image output format configuration.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
text TextResponseFormat?
Text output format configuration.
final

Methods

copyWith({Object? text = unsetCopyWithValue, Object? audio = unsetCopyWithValue, Object? image = unsetCopyWithValue}) ResponseFormatConfig
Creates a copy with replaced values.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Converts to JSON.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited