TaskType enum
Type of task for which the embedding will be used.
Values
- unspecified → const TaskType
-
Unspecified task type.
- retrievalQuery → const TaskType
-
Retrieval query.
- retrievalDocument → const TaskType
-
Retrieval document.
- semanticSimilarity → const TaskType
-
Semantic similarity.
- classification → const TaskType
-
Classification.
- clustering → const TaskType
-
Clustering.
- questionAnswering → const TaskType
-
Question answering.
- factVerification → const TaskType
-
Fact verification.
- codeRetrievalQuery → const TaskType
-
Code retrieval query.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited