TimeoutException class
Exception for request timeouts.
- Inheritance
-
- Object
- GoogleAIException
- TimeoutException
Constructors
- TimeoutException({required String message, required Duration timeout, required Duration elapsed, StackTrace? stackTrace, Exception? cause})
-
Creates a TimeoutException.
const
Properties
- cause → Exception?
-
Original exception that caused this exception (for exception chaining).
Used to preserve context through retry attempts and error transformations.
final
- elapsed → Duration
-
Elapsed time before timeout.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- message → String
-
Human-readable error message.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stackTrace → StackTrace?
-
Optional stack trace.
final
- timeout → Duration
-
Configured timeout duration.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited