ToolConfig class

The Tool configuration containing parameters for specifying Tool use in the request.

Constructors

ToolConfig({FunctionCallingConfig? functionCallingConfig, bool? includeServerSideToolInvocations, RetrievalConfig? retrievalConfig})
Creates a ToolConfig.
const
ToolConfig.fromJson(Map<String, dynamic> json)
Creates a ToolConfig from JSON.
factory

Properties

functionCallingConfig FunctionCallingConfig?
Function calling config.
final
hashCode int
The hash code for this object.
no setterinherited
includeServerSideToolInvocations bool?
Whether to include server-side tool invocations in the response.
final
retrievalConfig RetrievalConfig?
Retrieval config for tools like Google Search or FileSearch.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({Object? functionCallingConfig = unsetCopyWithValue, Object? includeServerSideToolInvocations = unsetCopyWithValue, Object? retrievalConfig = unsetCopyWithValue}) ToolConfig
Creates a copy with replaced values.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Converts to JSON.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited