TuningExamples class

Training examples for tuning.

Constructors

TuningExamples({List<TuningExample>? examples})
Creates a TuningExamples.
const
TuningExamples.fromJson(Map<String, dynamic> json)
Creates a TuningExamples from JSON.
factory

Properties

examples List<TuningExample>?
List of example pairs.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({Object? examples = unsetCopyWithValue}) TuningExamples
Creates a copy with replaced values.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Converts to JSON.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited