Video class

Representation of a video.

Constructors

Video({String? video, String? uri})
Creates a Video.
const
Video.fromJson(Map<String, dynamic> json)
Creates a Video from JSON.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
uri String?
Path to another storage (e.g., GCS URI).
final
video String?
Raw bytes (base64 encoded).
final

Methods

copyWith({Object? video = unsetCopyWithValue, Object? uri = unsetCopyWithValue}) Video
Creates a copy with replaced values.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Converts to JSON.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited