VideoMetadata class

Metadata for a video file.

Constructors

VideoMetadata({String? videoDuration})
Creates a VideoMetadata.
const
VideoMetadata.fromJson(Map<String, dynamic> json)
Creates a VideoMetadata from JSON.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
videoDuration String?
Duration of the video (format: google-duration, e.g., "3.5s").
final

Methods

copyWith({Object? videoDuration = unsetCopyWithValue}) VideoMetadata
Creates a copy with replaced values.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Converts to JSON.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited