VoiceConfig class

Configuration for voice selection.

Specifies which voice to use for audio output.

Constructors

VoiceConfig({PrebuiltVoiceConfig? prebuiltVoiceConfig})
Creates a VoiceConfig.
const
VoiceConfig.fromJson(Map<String, dynamic> json)
Creates from JSON.
factory
VoiceConfig.prebuilt(String voiceName)
Creates a configuration using a prebuilt voice.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
prebuiltVoiceConfig PrebuiltVoiceConfig?
Configuration for prebuilt voices.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

copyWith({Object? prebuiltVoiceConfig = unsetCopyWithValue}) VoiceConfig
Creates a copy with the given fields replaced.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Converts to JSON.
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited