WebhookInteractionCompletedEvent class

An interaction.completed webhook event.

Delivered when an interaction completes successfully.

Named WebhookInteractionCompletedEvent to avoid collision with the SSE InteractionCompletedEvent in interactions/events/.

Inheritance

Constructors

WebhookInteractionCompletedEvent({required String id, String? version, DateTime? timestamp})
Creates a WebhookInteractionCompletedEvent instance.
const
WebhookInteractionCompletedEvent.fromJson(Map<String, dynamic> json)
Creates a WebhookInteractionCompletedEvent from JSON.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
id String
The ID of the interaction.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timestamp DateTime?
The timestamp at which the event was emitted.
finalinherited
type String
The event type discriminator.
no setteroverride
version String?
The schema version (e.g. "v1").
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Converts to JSON.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited