ApiKeyCredentials class
API key authentication credentials.
- Inheritance
-
- Object
- AuthCredentials
- ApiKeyCredentials
Constructors
- ApiKeyCredentials(String apiKey, {AuthPlacement placement = AuthPlacement.queryParam})
-
Creates ApiKeyCredentials.
const
Properties
- apiKey → String
-
The API key to use for authentication.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- placement → AuthPlacement
-
Where to place the API key (query param or header).
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited