BidiGenerateContentRealtimeInput class
Real-time input message for streaming audio, video, or text.
Use this to send real-time input during a live session.
- Inheritance
-
- Object
- BidiGenerateContentClientMessage
- BidiGenerateContentRealtimeInput
Constructors
- BidiGenerateContentRealtimeInput({Blob? audio, Blob? video, String? text, bool? activityStart, bool? activityEnd, bool? audioStreamEnd})
-
Creates a BidiGenerateContentRealtimeInput.
const
-
BidiGenerateContentRealtimeInput.audio(List<
int> pcmBytes) -
Creates an audio input message.
factory
- BidiGenerateContentRealtimeInput.endActivity()
-
Creates an activity end signal (manual VAD).
factory
-
BidiGenerateContentRealtimeInput.fromJson(Map<
String, dynamic> json) -
Creates from JSON.
factory
- BidiGenerateContentRealtimeInput.startActivity()
-
Creates an activity start signal (manual VAD).
factory
- BidiGenerateContentRealtimeInput.textInput(String text)
-
Creates a text input message.
factory
Properties
- activityEnd → bool?
-
Signal that user activity has ended (manual VAD).
final
- activityStart → bool?
-
Signal that user activity has started (manual VAD).
final
- audio → Blob?
-
Audio data (16kHz, 16-bit signed little-endian mono PCM).
final
- audioStreamEnd → bool?
-
Signal that the audio stream has ended.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- text → String?
-
Text input.
final
- video → Blob?
-
Video frame data.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Converts to JSON with the message type wrapper key.
override
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited