BidiGenerateContentServerContent class
Server content message containing model output.
This is the main response message containing the model's generated content.
- Inheritance
-
- Object
- BidiGenerateContentServerMessage
- BidiGenerateContentServerContent
Constructors
- BidiGenerateContentServerContent({Content? modelTurn, bool? turnComplete, bool? generationComplete, bool? interrupted, Transcription? inputTranscription, Transcription? outputTranscription, GroundingMetadata? groundingMetadata, UsageMetadata? usageMetadata})
-
Creates a BidiGenerateContentServerContent.
const
-
BidiGenerateContentServerContent.fromJson(Map<
String, dynamic> json) -
Creates from JSON.
factory
Properties
- generationComplete → bool?
-
Whether generation is fully complete.
final
- groundingMetadata → GroundingMetadata?
-
Grounding metadata for the response.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- inputTranscription → Transcription?
-
Transcription of the user's input audio.
final
- interrupted → bool?
-
Whether the model was interrupted.
final
- modelTurn → Content?
-
The model's generated content for this turn.
final
- outputTranscription → Transcription?
-
Transcription of the model's output audio.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- turnComplete → bool?
-
Whether the model's turn is complete.
final
- usageMetadata → UsageMetadata?
-
Token usage metadata.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Converts to JSON with the message type wrapper key.
override
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited