CodeExecutionResultStep class
Result of a code execution call.
- Inheritance
-
- Object
- InteractionStep
- CodeExecutionResultStep
Constructors
- CodeExecutionResultStep({required String callId, required String result, bool? isError, String? signature})
-
Creates a CodeExecutionResultStep instance.
const
-
CodeExecutionResultStep.fromJson(Map<
String, dynamic> json) -
Creates a CodeExecutionResultStep from JSON.
factory
Properties
- callId → String
-
ID matching the corresponding CodeExecutionCallStep.id.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isError → bool?
-
Whether the code execution resulted in an error.
final
- result → String
-
The output of the code execution.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- signature → String?
-
Signature hash for backend validation.
final
- type → String
-
The type discriminator for this step.
no setteroverride
Methods
-
copyWith(
{Object? callId = unsetCopyWithValue, Object? result = unsetCopyWithValue, Object? isError = unsetCopyWithValue, Object? signature = unsetCopyWithValue}) → CodeExecutionResultStep - Creates a copy with replaced values.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Converts to JSON.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited