ExaAISearchConfig class
Configuration for ExaAISearch.
Constructors
-
ExaAISearchConfig({required String apiKey, Map<
String, dynamic> ? customConfig}) -
Creates an ExaAISearchConfig instance.
const
-
ExaAISearchConfig.fromJson(Map<
String, dynamic> json) -
Creates an ExaAISearchConfig from JSON.
factory
Properties
- apiKey → String
-
Required. The API key for ExaAiSearch.
final
-
customConfig
→ Map<
String, dynamic> ? -
Optional. This field can be used to pass any parameter from the Exa.ai
Search API.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{Object? apiKey = unsetCopyWithValue, Object? customConfig = unsetCopyWithValue}) → ExaAISearchConfig - Creates a copy with replaced values.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Converts to JSON.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited