FileSearchCustomMetadata class
User-provided custom metadata stored as key-value pairs for file search.
Constructors
-
FileSearchCustomMetadata({required String key, String? stringValue, double? numericValue, List<
String> ? stringListValue}) -
Creates a FileSearchCustomMetadata.
const
-
FileSearchCustomMetadata.fromJson(Map<
String, dynamic> json) -
Creates a FileSearchCustomMetadata from JSON.
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → String
-
Required. The key of the metadata to store.
final
- numericValue → double?
-
The numeric value of the metadata to store.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
stringListValue
→ List<
String> ? -
The StringList value of the metadata to store.
final
- stringValue → String?
-
The string value of the metadata to store.
final
Methods
-
copyWith(
{String? key, Object? stringValue = unsetCopyWithValue, Object? numericValue = unsetCopyWithValue, Object? stringListValue = unsetCopyWithValue}) → FileSearchCustomMetadata - Creates a copy with replaced values.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Converts to JSON.
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited