FunctionCallingConfig class
Configuration for specifying function calling behavior.
Constructors
-
FunctionCallingConfig({FunctionCallingMode? mode, List<
String> ? allowedFunctionNames}) -
Creates a FunctionCallingConfig.
const
-
FunctionCallingConfig.fromJson(Map<
String, dynamic> json) -
Creates a FunctionCallingConfig from JSON.
factory
Properties
-
allowedFunctionNames
→ List<
String> ? -
A set of function names that, when provided, limits the functions
the model will call.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- mode → FunctionCallingMode?
-
Specifies the mode in which function calling should execute.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{Object? mode = unsetCopyWithValue, Object? allowedFunctionNames = unsetCopyWithValue}) → FunctionCallingConfig - Creates a copy with replaced values.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Converts to JSON.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited