FunctionDeclaration class
Structured representation of a function declaration.
Constructors
- FunctionDeclaration({required String name, required String description, Schema? parameters})
-
Creates a FunctionDeclaration.
const
-
FunctionDeclaration.fromJson(Map<
String, dynamic> json) -
Creates a FunctionDeclaration from JSON.
factory
Properties
- description → String
-
Description of what the function does.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
The name of the function.
final
- parameters → Schema?
-
Parameters for the function (as a Schema object).
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{Object? name = unsetCopyWithValue, Object? description = unsetCopyWithValue, Object? parameters = unsetCopyWithValue}) → FunctionDeclaration - Creates a copy with replaced values.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Converts to JSON.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited