FunctionResponseScheduling enum
Scheduling options for function responses.
Values
- schedulingUnspecified → const FunctionResponseScheduling
-
Unspecified scheduling.
- silent → const FunctionResponseScheduling
-
Only add the result to the conversation context, do not interrupt or trigger generation.
- whenIdle → const FunctionResponseScheduling
-
Add the result to the conversation context, and prompt to generate output without interrupting ongoing generation.
- interrupt → const FunctionResponseScheduling
-
Add the result to the conversation context, interrupt ongoing generation and prompt to generate output.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → String - Converts to JSON.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
FunctionResponseScheduling> - A constant List of the values in this enum, in order of their declaration.