FunctionResultSubcontentImage class
An ImageContent used as function result subcontent.
- Inheritance
-
- Object
- FunctionResultSubcontent
- FunctionResultSubcontentImage
Constructors
- FunctionResultSubcontentImage(ImageContent content)
-
Creates a FunctionResultSubcontentImage wrapping
content.const
Properties
- content → ImageContent
-
The wrapped image content.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → String
-
The type discriminator for this subcontent.
no setteroverride
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Converts to JSON.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited