GenerateContentBatch class
A resource representing a batch of GenerateContent requests.
Constructors
- GenerateContentBatch({String? displayName, String? model, InputConfig? inputConfig, String? name, GenerateContentBatchOutput? output, DateTime? createTime, DateTime? endTime, DateTime? updateTime, BatchStats? batchStats, BatchState? state, int? priority})
-
Creates a GenerateContentBatch.
const
-
GenerateContentBatch.fromJson(Map<
String, dynamic> json) -
Creates a GenerateContentBatch from JSON.
factory
Properties
- batchStats → BatchStats?
-
Stats about the batch.
final
- createTime → DateTime?
-
The time at which the batch was created.
final
- displayName → String?
-
The user-defined name of this batch.
final
- endTime → DateTime?
-
The time at which the batch processing completed.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- inputConfig → InputConfig?
-
Input configuration of the instances on which batch processing is performed.
final
- model → String?
-
The name of the
Modelto use for generating the completion.final - name → String?
-
The resource name of the batch.
final
- output → GenerateContentBatchOutput?
-
The output of the batch request.
final
- priority → int?
-
The priority of the batch.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- state → BatchState?
-
The state of the batch.
final
- updateTime → DateTime?
-
The time at which the batch was last updated.
final
Methods
-
copyWith(
{Object? name = unsetCopyWithValue, Object? displayName = unsetCopyWithValue, Object? model = unsetCopyWithValue, Object? inputConfig = unsetCopyWithValue, Object? output = unsetCopyWithValue, Object? createTime = unsetCopyWithValue, Object? endTime = unsetCopyWithValue, Object? updateTime = unsetCopyWithValue, Object? batchStats = unsetCopyWithValue, Object? state = unsetCopyWithValue, Object? priority = unsetCopyWithValue}) → GenerateContentBatch - Creates a copy with replaced values.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Converts to JSON.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited