GoogleMapsCallStepArguments class
The arguments to pass to the Google Maps tool.
Constructors
-
GoogleMapsCallStepArguments({List<
String> ? queries}) -
Creates a GoogleMapsCallStepArguments instance.
const
-
GoogleMapsCallStepArguments.fromJson(Map<
String, dynamic> json) -
Creates from JSON.
factory
Properties
Methods
-
copyWith(
{Object? queries = unsetCopyWithValue}) → GoogleMapsCallStepArguments - Creates a copy with replaced values.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Converts to JSON.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited