GoogleMapsResultStep class
Result of a Google Maps call.
- Inheritance
-
- Object
- InteractionStep
- GoogleMapsResultStep
Constructors
-
GoogleMapsResultStep({required String callId, required List<
GoogleMapsResultItem> result, String? signature}) -
Creates a GoogleMapsResultStep instance.
const
-
GoogleMapsResultStep.fromJson(Map<
String, dynamic> json) -
Creates a GoogleMapsResultStep from JSON.
factory
Properties
- callId → String
-
ID matching the corresponding GoogleMapsCallStep.id.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
result
→ List<
GoogleMapsResultItem> -
The results of the Google Maps query.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- signature → String?
-
Signature hash for backend validation.
final
- type → String
-
The type discriminator for this step.
no setteroverride
Methods
-
copyWith(
{Object? callId = unsetCopyWithValue, Object? result = unsetCopyWithValue, Object? signature = unsetCopyWithValue}) → GoogleMapsResultStep - Creates a copy with replaced values.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Converts to JSON.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited