GroundingAttribution class
Attribution for a source that contributed to an answer.
This is populated for GenerateAnswer calls.
Constructors
- GroundingAttribution({Content? content, AttributionSourceId? sourceId})
-
Creates a GroundingAttribution.
const
-
GroundingAttribution.fromJson(Map<
String, dynamic> json) -
Creates a GroundingAttribution from JSON.
factory
Properties
- content → Content?
-
Grounding source content that makes up this attribution.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sourceId → AttributionSourceId?
-
Output only. Identifier for the source contributing to this attribution.
final
Methods
-
copyWith(
{Object? content = unsetCopyWithValue, Object? sourceId = unsetCopyWithValue}) → GroundingAttribution - Creates a copy with replaced values.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Converts to JSON.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited