GroundingChunkCustomMetadata class
Custom metadata associated with a grounding chunk.
Constructors
- GroundingChunkCustomMetadata({String? key, double? numericValue, GroundingChunkStringList? stringListValue, String? stringValue})
-
Creates a GroundingChunkCustomMetadata.
const
-
GroundingChunkCustomMetadata.fromJson(Map<
String, dynamic> json) -
Creates a GroundingChunkCustomMetadata from JSON.
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → String?
-
Optional. Key of the metadata.
final
- numericValue → double?
-
Optional. Numeric value of the metadata.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stringListValue → GroundingChunkStringList?
-
Optional. String list value of the metadata.
final
- stringValue → String?
-
Optional. String value of the metadata.
final
Methods
-
copyWith(
{Object? key = unsetCopyWithValue, Object? numericValue = unsetCopyWithValue, Object? stringListValue = unsetCopyWithValue, Object? stringValue = unsetCopyWithValue}) → GroundingChunkCustomMetadata - Creates a copy with replaced values.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Converts to JSON.
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited