ImportFileRequest class
Request for ImportFile to import a File API file with a FileSearchStore.
Constructors
-
ImportFileRequest({required String fileName, List<
FileSearchCustomMetadata> ? customMetadata, ChunkingConfig? chunkingConfig}) -
Creates an ImportFileRequest.
const
-
ImportFileRequest.fromJson(Map<
String, dynamic> json) -
Creates an ImportFileRequest from JSON.
factory
Properties
- chunkingConfig → ChunkingConfig?
-
Optional. Config for telling the service how to chunk the file.
final
-
customMetadata
→ List<
FileSearchCustomMetadata> ? -
Custom metadata to be associated with the file.
final
- fileName → String
-
Required. The name of the
Fileto import.final - hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{String? fileName, Object? customMetadata = unsetCopyWithValue, Object? chunkingConfig = unsetCopyWithValue}) → ImportFileRequest - Creates a copy with replaced values.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Converts to JSON.
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited