ImportFileResponse class
Response for ImportFile to import a File API file with a FileSearchStore.
Constructors
- ImportFileResponse({String? parent, String? documentName})
-
Creates an ImportFileResponse.
const
-
ImportFileResponse.fromJson(Map<
String, dynamic> json) -
Creates an ImportFileResponse from JSON.
factory
Properties
- documentName → String?
-
Immutable. Identifier. The identifier for the
Documentimported.final - hashCode → int
-
The hash code for this object.
no setterinherited
- parent → String?
-
The name of the
FileSearchStorecontainingDocuments.final - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{Object? parent = unsetCopyWithValue, Object? documentName = unsetCopyWithValue}) → ImportFileResponse - Creates a copy with replaced values.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Converts to JSON.
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited