InlinedEmbedContentResponse class
A single embed response in a batch with optional metadata and error.
Constructors
-
InlinedEmbedContentResponse({Status? error, EmbedContentResponse? response, Map<
String, dynamic> ? metadata}) -
Creates an InlinedEmbedContentResponse.
const
-
InlinedEmbedContentResponse.fromJson(Map<
String, dynamic> json) -
Creates an InlinedEmbedContentResponse from JSON.
factory
Properties
- error → Status?
-
The error encountered while processing the request (if any).
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
metadata
→ Map<
String, dynamic> ? -
Metadata associated with the request.
final
- response → EmbedContentResponse?
-
The response to the request (if successful).
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{Object? error = unsetCopyWithValue, Object? response = unsetCopyWithValue, Object? metadata = unsetCopyWithValue}) → InlinedEmbedContentResponse - Creates a copy with replaced values.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Converts to JSON.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited