InlinedRequest class
A single request in a batch with optional metadata.
Constructors
-
InlinedRequest({required GenerateContentRequest request, Map<
String, dynamic> ? metadata}) -
Creates an InlinedRequest.
const
-
InlinedRequest.fromJson(Map<
String, dynamic> json) -
Creates an InlinedRequest from JSON.
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
metadata
→ Map<
String, dynamic> ? -
Optional metadata to be associated with the request.
final
- request → GenerateContentRequest
-
The request to be processed in the batch.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{Object? request = unsetCopyWithValue, Object? metadata = unsetCopyWithValue}) → InlinedRequest - Creates a copy with replaced values.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Converts to JSON.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited