InputConfig class
Constructors
- InputConfig({String? fileName, InlinedRequests? requests})
-
Creates an InputConfig.
const
-
InputConfig.fromJson(Map<
String, dynamic> json) -
Creates an InputConfig from JSON.
factory
Properties
- fileName → String?
-
The name of the
Filecontaining the input requests.final - hashCode → int
-
The hash code for this object.
no setterinherited
- requests → InlinedRequests?
-
The requests to be processed in the batch (inline).
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{Object? fileName = unsetCopyWithValue, Object? requests = unsetCopyWithValue}) → InputConfig - Creates a copy with replaced values.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Converts to JSON.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited