InputFeedback class
Feedback related to the input data used to answer the question, as opposed to the model-generated response to the question.
The input data can be one or more of the following:
- Question specified by the last entry in
GenerateAnswerRequest.content - Conversation history specified by the other entries in
GenerateAnswerRequest.content - Grounding sources (
GenerateAnswerRequest.semantic_retrieverorGenerateAnswerRequest.inline_passages)
Constructors
-
InputFeedback({BlockReason? blockReason, List<
SafetyRating> ? safetyRatings}) -
Creates an InputFeedback.
const
-
InputFeedback.fromJson(Map<
String, dynamic> json) -
Creates an InputFeedback from JSON.
factory
Properties
- blockReason → BlockReason?
-
Optional. If set, the input was blocked and no candidates are returned.
Rephrase the input.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
safetyRatings
→ List<
SafetyRating> ? -
Ratings for safety of the input.
There is at most one rating per category.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Converts to JSON.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited