InteractionCreatedEvent class
An event indicating that an interaction has been created.
Emitted at the start of an SSE stream and carries the initial
Interaction resource (with empty steps).
- Inheritance
-
- Object
- InteractionEvent
- InteractionCreatedEvent
Constructors
- InteractionCreatedEvent({required Interaction interaction, StreamMetadata? metadata, String? eventId})
-
Creates an InteractionCreatedEvent instance.
const
-
InteractionCreatedEvent.fromJson(Map<
String, dynamic> json) -
Creates an InteractionCreatedEvent from JSON.
factory
Properties
- eventId → String?
-
The event ID token to resume the stream from this event.
finalinherited
- eventType → String
-
The event type discriminator.
no setteroverride
- hashCode → int
-
The hash code for this object.
no setterinherited
- interaction → Interaction
-
The created interaction.
final
- metadata → StreamMetadata?
-
Optional metadata accompanying this streamed event.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Converts to JSON.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited