InteractionImageResponseFormatAspectRatio enum
Aspect ratio for an image response.
Values
- ratio1x1 → const InteractionImageResponseFormatAspectRatio
-
1:1 aspect ratio.
- ratio2x3 → const InteractionImageResponseFormatAspectRatio
-
2:3 aspect ratio.
- ratio3x2 → const InteractionImageResponseFormatAspectRatio
-
3:2 aspect ratio.
- ratio3x4 → const InteractionImageResponseFormatAspectRatio
-
3:4 aspect ratio.
- ratio4x3 → const InteractionImageResponseFormatAspectRatio
-
4:3 aspect ratio.
- ratio4x5 → const InteractionImageResponseFormatAspectRatio
-
4:5 aspect ratio.
- ratio5x4 → const InteractionImageResponseFormatAspectRatio
-
5:4 aspect ratio.
- ratio9x16 → const InteractionImageResponseFormatAspectRatio
-
9:16 aspect ratio.
- ratio16x9 → const InteractionImageResponseFormatAspectRatio
-
16:9 aspect ratio.
- ratio21x9 → const InteractionImageResponseFormatAspectRatio
-
21:9 aspect ratio.
- ratio1x8 → const InteractionImageResponseFormatAspectRatio
-
1:8 aspect ratio.
- ratio8x1 → const InteractionImageResponseFormatAspectRatio
-
8:1 aspect ratio.
- ratio1x4 → const InteractionImageResponseFormatAspectRatio
-
1:4 aspect ratio.
- ratio4x1 → const InteractionImageResponseFormatAspectRatio
-
4:1 aspect ratio.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
InteractionImageResponseFormatAspectRatio> - A constant List of the values in this enum, in order of their declaration.