InteractionTextResponseFormat class
Configuration for text output format.
- Inheritance
-
- Object
- InteractionResponseFormat
- InteractionTextResponseFormat
Constructors
-
InteractionTextResponseFormat({InteractionTextResponseFormatMimeType? mimeType, Map<
String, dynamic> ? schema}) -
Creates an InteractionTextResponseFormat instance.
const
-
InteractionTextResponseFormat.fromJson(Map<
String, dynamic> json) -
Creates an InteractionTextResponseFormat from JSON.
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- mimeType → InteractionTextResponseFormatMimeType?
-
The MIME type of the text output.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
schema
→ Map<
String, dynamic> ? -
JSON schema that the output should conform to. Only applicable when
mimeType is InteractionTextResponseFormatMimeType.applicationJson.
final
- type → String
-
The type discriminator for this response format.
no setteroverride
Methods
-
copyWith(
{Object? mimeType = unsetCopyWithValue, Object? schema = unsetCopyWithValue}) → InteractionTextResponseFormat - Creates a copy with replaced values.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Converts to JSON.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited