LiveSessionException class
Exception thrown for general Live session errors.
- Inheritance
-
- Object
- GoogleAIException
- LiveSessionException
Constructors
- LiveSessionException({required String message, StackTrace? stackTrace, Exception? cause})
-
Creates a LiveSessionException.
const
Properties
- cause → Exception?
-
Original exception that caused this exception (for exception chaining).
Used to preserve context through retry attempts and error transformations.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- message → String
-
Human-readable error message.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stackTrace → StackTrace?
-
Optional stack trace.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited