PredictLongRunningResponse class
Response message for PredictLongRunning operation.
Constructors
- PredictLongRunningResponse({PredictLongRunningGeneratedVideoResponse? generateVideoResponse})
-
Creates a PredictLongRunningResponse.
const
-
PredictLongRunningResponse.fromJson(Map<
String, dynamic> json) -
Creates a PredictLongRunningResponse from JSON.
factory
Properties
- generateVideoResponse → PredictLongRunningGeneratedVideoResponse?
-
The response of the video generation prediction.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{Object? generateVideoResponse = unsetCopyWithValue}) → PredictLongRunningResponse - Creates a copy with replaced values.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Converts to JSON.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited