PredictRequest class
Request message for Predict operation.
Used for synchronous prediction requests to models like Veo for video generation.
Constructors
- PredictRequest({required List instances, dynamic parameters})
-
Creates a PredictRequest.
const
-
PredictRequest.fromJson(Map<
String, dynamic> json) -
Creates a PredictRequest from JSON.
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- instances → List
-
Required. The instances that are the input to the prediction call.
final
- parameters → dynamic
-
Optional. The parameters that govern the prediction call.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{Object? instances = unsetCopyWithValue, Object? parameters = unsetCopyWithValue}) → PredictRequest - Creates a copy with replaced values.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Converts to JSON.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited