ResponseMetadata class
Metadata about the HTTP response that caused an error.
Constructors
-
ResponseMetadata({required int statusCode, required Map<
String, String> headers, required String bodyExcerpt, required Duration latency}) -
Creates ResponseMetadata.
const
Properties
- bodyExcerpt → String
-
Excerpt of response body (first 200 chars, redacted).
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
headers
→ Map<
String, String> -
Response headers.
final
- latency → Duration
-
Request latency.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- statusCode → int
-
HTTP status code.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited