RetrievalConfig class
Retrieval config.
Constructors
- RetrievalConfig({LatLng? latLng, String? languageCode})
-
Creates a RetrievalConfig.
const
-
RetrievalConfig.fromJson(Map<
String, dynamic> json) -
Creates a RetrievalConfig from JSON.
factory
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- languageCode → String?
-
Optional. The language code of the user.
final
- latLng → LatLng?
-
Optional. The location of the user.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
copyWith(
{Object? latLng = unsetCopyWithValue, Object? languageCode = unsetCopyWithValue}) → RetrievalConfig - Creates a copy with replaced values.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> - Converts to JSON.
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited