StepDeltaEvent class
An event carrying a partial update for a step in the interaction.
- Inheritance
-
- Object
- InteractionEvent
- StepDeltaEvent
Constructors
- StepDeltaEvent({required int index, required StepDeltaData delta, StreamMetadata? metadata, String? eventId})
-
Creates a StepDeltaEvent instance.
const
-
StepDeltaEvent.fromJson(Map<
String, dynamic> json) -
Creates a StepDeltaEvent from JSON.
factory
Properties
- delta → StepDeltaData
-
The delta payload for the step.
final
- eventId → String?
-
The event ID token to resume the stream from this event.
finalinherited
- eventType → String
-
The event type discriminator.
no setteroverride
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
The index of the step in the interaction's
stepslist.final - metadata → StreamMetadata?
-
Optional metadata accompanying this streamed event.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Converts to JSON.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited