UrlContextResultDelta class
A URL context result delta update.
- Inheritance
-
- Object
- InteractionDelta
- UrlContextResultDelta
Constructors
-
UrlContextResultDelta({String? callId, List<
UrlContextResult> ? result, bool? isError, String? signature}) -
Creates a UrlContextResultDelta instance.
const
-
UrlContextResultDelta.fromJson(Map<
String, dynamic> json) -
Creates a UrlContextResultDelta from JSON.
factory
Properties
- callId → String?
-
ID to match the ID from the URL context call.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isError → bool?
-
Whether the URL context resulted in an error.
final
-
result
→ List<
UrlContextResult> ? -
The results of the URL context.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- signature → String?
-
The signature of the URL context result.
final
- type → String
-
The type discriminator for this delta.
no setteroverride
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Converts to JSON.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited