UserInputStep class
A user-input step.
Represents input provided by the user, typically containing media-only InteractionContent items (text, image, audio, document, video).
- Inheritance
-
- Object
- InteractionStep
- UserInputStep
Constructors
-
UserInputStep({List<
InteractionContent> ? content}) -
Creates a UserInputStep instance.
const
-
UserInputStep.fromJson(Map<
String, dynamic> json) -
Creates a UserInputStep from JSON.
factory
Properties
-
content
→ List<
InteractionContent> ? -
The content of the user input.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → String
-
The type discriminator for this step.
no setteroverride
Methods
-
copyWith(
{Object? content = unsetCopyWithValue}) → UserInputStep - Creates a copy with replaced values.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Converts to JSON.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited