VideoContent class
A video content block.
- Inheritance
-
- Object
- InteractionContent
- VideoContent
Constructors
- VideoContent({String? data, String? uri, String? mimeType, String? resolution})
-
Creates a VideoContent instance.
const
-
VideoContent.fromJson(Map<
String, dynamic> json) -
Creates a VideoContent from JSON.
factory
Properties
- data → String?
-
Base64-encoded video data.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- mimeType → String?
-
The MIME type of the video.
final
- resolution → String?
-
The resolution of the media.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → String
-
The type discriminator for this content.
no setteroverride
- uri → String?
-
URI of the video.
final
Methods
-
copyWith(
{Object? data = unsetCopyWithValue, Object? uri = unsetCopyWithValue, Object? mimeType = unsetCopyWithValue, Object? resolution = unsetCopyWithValue}) → VideoContent - Creates a copy with replaced values.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Converts to JSON.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited