VideoMetadataPart class
Video timing/sampling metadata.
Constructors
- VideoMetadataPart(VideoMetadata videoMetadata)
-
Creates a VideoMetadataPart.
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- videoMetadata → VideoMetadata
-
Video metadata.
final
Methods
-
copyWith(
{Object? videoMetadata = unsetCopyWithValue}) → VideoMetadataPart - Creates a copy with replaced values.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Converts to JSON.
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited